@@ -186,7 +186,7 @@ public:
 
 GameArea::GameArea()
  : minFont(Lum::OS::display->GetFont()),
-   markFont(Lum::OS::display->GetFontByPixel(Lum::OS::Display::fontTypeProportional,7)),
+   minMarkFont(Lum::OS::display->GetFontByPixel(Lum::OS::Display::fontTypeProportional,7)),
    font(Lum::OS::display->GetFont(Lum::OS::Display::fontScaleCaption1)),
    presetColor(0.5,0.5,0.5,Lum::OS::display->GetColor(Lum::OS::Display::whiteColor)),
    focusBackgroundColor(0.8,0.8,0.8,Lum::OS::display->GetColor(Lum::OS::Display::fillColor)),
@@ -291,43 +291,34 @@ void GameArea::CalcSize()
   size_t markBoxSize=0;
   size_t minBoxSize=0;
 
+  // Size of box containing "normal" content text
   for (size_t i=1; i<=Sudoku::dimension; i++) {
-    Lum::OS::FontExtent extent;
-
-    minFont->StringExtent(Lum::Base::NumberToWString(i),extent,Lum::OS::Font::bold);
-
-    minBoxSize=std::max(minBoxSize,extent.width-extent.left-extent.right);
-    minBoxSize=std::max(minBoxSize,extent.height);
+    minBoxSize=std::max(minBoxSize,minFont->StringWidth(Lum::Base::NumberToWString(i),
+                                                        Lum::OS::Font::bold));
+    minBoxSize=std::max(minBoxSize,font->pixelHeight);
   }
 
-  minBoxSize+=2*Lum::OS::display->GetSpaceHorizontal(Lum::OS::Display::spaceObjectBorder);
-
+  // Size of box if containing markers (3x3 array)
   for (size_t i=1; i<=Sudoku::dimension; i++) {
-    Lum::OS::FontExtent extent;
-
-    markFont->StringExtent(Lum::Base::NumberToWString(i),extent,Lum::OS::Font::normal);
-
-    markBoxSize=std::max(markBoxSize,extent.width-extent.left-extent.right);
-    markBoxSize=std::max(markBoxSize,extent.height);
+    markBoxSize=std::max(markBoxSize,
+                         minMarkFont->StringWidth(Lum::Base::NumberToWString(i)));
+    markBoxSize=std::max(markBoxSize,minMarkFont->pixelHeight);
   }
 
   markBoxSize*=3;
 
+  // size of area containing of 9x9 boxes with lines in between
   minWidth=(3+1)*1+(9+1)*1+9*std::max(minBoxSize,markBoxSize);
   minHeight=(3+1)*1+(9+1)*1+9*std::max(minBoxSize,markBoxSize);
 
+  // now the current with depending on the current font
   boxSize=0;
   for (size_t i=1; i<=9; i++) {
-    Lum::OS::FontExtent extent;
-
-    font->StringExtent(Lum::Base::NumberToWString(i),extent,Lum::OS::Font::bold);
-
-    boxSize=std::max(boxSize,extent.width-extent.left-extent.right);
-    boxSize=std::max(boxSize,extent.height);
+    boxSize=std::max(boxSize,font->StringWidth(Lum::Base::NumberToWString(i),
+                                               Lum::OS::Font::bold));
+    boxSize=std::max(boxSize,font->pixelHeight);
   }
 
-  boxSize+=2*Lum::OS::display->GetSpaceHorizontal(Lum::OS::Display::spaceObjectBorder);
-
   size=(3+1)*1+(9+1)*1+9*std::max(markBoxSize,boxSize);
 
   width=size;
@@ -336,32 +327,33 @@ void GameArea::CalcSize()
   Object::CalcSize();
 }
 
-Lum::OS::Font* GameArea::FindFont(size_t size)
+/**
+  * Find the font that can show dimensions number with in a box of size x size..
+  */
+Lum::OS::Font* GameArea::FindFont(Lum::OS::Font* minFont, size_t size)
 {
   Lum::OS::FontRef font;
   bool             fits;
   size_t           fontSize;
 
-  font=Lum::OS::display->GetFont();
+  font=minFont;
   fontSize=font->pixelHeight+1;
 
   do {
     Lum::OS::FontRef tmpFont;
     size_t           boxSize=0;
 
-    tmpFont=Lum::OS::display->GetFontByPixel(Lum::OS::Display::fontTypeProportional,fontSize);
+    tmpFont=Lum::OS::display->GetFontByPixel(Lum::OS::Display::fontTypeProportional,
+                                             fontSize);
 
     if (tmpFont.Valid()) {
       for (size_t i=1; i<=Sudoku::dimension; i++) {
-        Lum::OS::FontExtent extent;
-
-        tmpFont->StringExtent(Lum::Base::NumberToWString(i),extent,Lum::OS::Font::bold);
-
-        boxSize=std::max(boxSize,extent.width-extent.left-extent.right);
-        boxSize=std::max(boxSize,extent.height);
+        boxSize=std::max(boxSize,tmpFont->StringWidth(Lum::Base::NumberToWString(i),
+                                                      Lum::OS::Font::bold));
+        boxSize=std::max(boxSize,tmpFont->pixelHeight);
       }
 
-      fits=(boxSize<=size) && (fontSize<=size);
+      fits=boxSize<=size && fontSize<=size;
     }
     else {
       fits=fontSize<=size;
@@ -377,6 +369,19 @@ Lum::OS::Font* GameArea::FindFont(size_t size)
   return font.Get();
 }
 
+void GameArea::Layout()
+{
+  boxSize=std::min((width-(3+1)*1-(9+1)*1)/9,
+                   (height-(3+1)*1-(9+1)*1)/9);
+
+  size=(3+1)*1+(9+1)*1+9*boxSize;
+
+  font=FindFont(minFont,boxSize);
+  markFont=FindFont(minMarkFont,boxSize/3);
+
+  Object::Layout();
+}
+
 void GameArea::Draw(int x, int y, size_t w, size_t h)
 {
   Object::Draw(x,y,w,h);
@@ -390,10 +395,6 @@ void GameArea::Draw(int x, int y, size_t w, size_t h)
   Lum::OS::DrawInfo *draw=GetDrawInfo();
   size_t            offset;
 
-  boxSize=std::min((width-(3+1)*1-(9+1)*1)/9,(height-(3+1)*1-(9+1)*1)/9);
-
-  size=(3+1)*1+(9+1)*1+9*boxSize;
-
   //
   // Draw game area
   //
@@ -423,8 +424,6 @@ void GameArea::Draw(int x, int y, size_t w, size_t h)
   }
   draw->PopForeground();
 
-  font=FindFont(boxSize-2*Lum::OS::display->GetSpaceHorizontal(Lum::OS::Display::spaceObjectBorder));
-
   //
   // Draw values
   //
