@@ -135,7 +135,6 @@ private:
   Lum::Model::ActionRef         helpAction;
   Lum::Model::ActionRef         aboutAction;
   GameArea                      *gameArea;
-  Lum::Text                     *rating;
   GenerateTask                  generateTask;
   Lum::Model::BooleanRef        keypad[Sudoku::dimension];
   Lum::Model::BooleanRef        mark;
@@ -153,7 +152,6 @@ public:
     helpAction(new Lum::Model::Action),
     aboutAction(new Lum::Model::Action),
     gameArea(new GameArea()),
-    rating(NULL),
     mark(new Lum::Model::Boolean(false)),
     lock(false),
     statisticsImage(new Lum::Images::StatefulImage()),
@@ -192,7 +190,6 @@ public:
   void PreInit()
   {
     Lum::Array *array;
-    Lum::Label *label;
     Lum::Panel *horiz,*vert;
 
     horiz=Lum::HPanel::Create(true,true);
@@ -206,21 +203,7 @@ public:
 
     vert=Lum::VPanel::Create(false,true);
 
-    label=Lum::Label::Create(true,false);
-
-    rating=new Lum::Text();
-    rating->SetFlex(true,false);
-    rating->SetWidth(Lum::Base::Size::stdCharWidth,7);
-    rating->SetAlignment(Lum::Text::right);
-    rating->SetStyle(Lum::OS::Font::bold);
-    rating->SetText(L"0");
-    label->AddLabel(_(L"POINTS_WEIGHT",L"Weight:"),rating);
-
-    vert->Add(label);
-
     if (true/*Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()*/) {
-      vert->AddSpace();
-
       array=new Lum::Array();
       array->SetFlex(true,true);
       array->SetHorizontalCount(3);
@@ -462,12 +445,7 @@ public:
 
   void SetRiddle()
   {
-    char value[20];
-
-    sprintf(value,"%.0f",generateTask.weight.rating);
-
     gameArea->SetModel(riddle,solution);
-    rating->SetText(Lum::Base::StringToWString(value));
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -478,7 +456,6 @@ public:
         if (game!=NULL) {
           Sudoku         riddle,solution;
           Sudoku::Weight weight;
-          char           value[20];
 
           riddle.SetAreaAsString(game->riddle);
           solution.SetAreaAsString(game->solution);
@@ -487,9 +464,6 @@ public:
 
           gameArea->SetGame(*game);
 
-          sprintf(value,"%.0f",weight.rating);
-          rating->SetText(Lum::Base::StringToWString(value));
-
           delete game;
           game=NULL;
         }
